@@ -476,7 +476,7 @@ class EPN(models.Model):
         return super(EPN, self).save(*args, **kwargs)
 
     class Meta:
-        ordering = ('epn')
+        ordering = ('epn', )
 
 
 class IPNManager(models.Model):
