@@ -5,16 +5,30 @@ from django.conf import settings
 from django.core.files.uploadedfile import SimpleUploadedFile
 from django.test import TestCase
 
-from django_libs.tests.mixins import ViewTestMixin
+from django_libs.tests.mixins import ViewTestMixin, ViewRequestFactoryTestMixin
 from django_libs.tests.factories import UserFactory
 
-from .factories import (
-    CBOMFactory,
-    CompanyFactory,
-    EPNFactory,
-    IPNFactory,
-    UnitFactory,
-)
+from .. import views
+from . import factories
+
+
+class DropDownChoicesAJAXViewTestCase(ViewRequestFactoryTestMixin, TestCase):
+    """Tests for the ``DropDownChoicesAJAXView`` view class."""
+    view_class = views.DropDownChoicesAJAXView
+
+    def setUp(self):
+        self.user = UserFactory()
+        self.company = factories.CompanyFactory()
+        self.epn = factories.EPNFactory(company=self.company)
+        self.data = {
+            'action': 'get_epn_choices_for_customer',
+            'obj_id': self.company.id,
+        }
+
+    def test_view(self):
+        self.should_redirect_to_login_when_anonymous()
+        self.is_not_callable(user=self.user)
+        self.is_callable(user=self.user, ajax=True, data=self.data)
 
 
 class BOMUploadViewTestCase(ViewTestMixin, TestCase):
@@ -29,11 +43,11 @@ class BOMUploadViewTestCase(ViewTestMixin, TestCase):
 
     def setUp(self):
         self.user = UserFactory()
-        self.unit = UnitFactory(code='pcs', description='pieces')
+        self.unit = factories.UnitFactory(code='pcs', description='pieces')
 
-        self.ipn = IPNFactory()
-        IPNFactory(code='7900.1500')
-        IPNFactory(code='6030.2345')
+        self.ipn = factories.IPNFactory()
+        factories.IPNFactory(code='7900.1500')
+        factories.IPNFactory(code='6030.2345')
 
         self.csv_file = open(os.path.join(
             settings.APP_ROOT, 'tests/files/BOM.csv'))
@@ -68,7 +82,7 @@ class CBOMDownloadViewTestCase(ViewTestMixin, TestCase):
 
     def setUp(self):
         self.user = UserFactory()
-        self.cbom = CBOMFactory()
+        self.cbom = factories.CBOMFactory()
 
     def test_view(self):
         self.should_redirect_to_login_when_anonymous()
@@ -91,11 +105,11 @@ class CBOMUploadViewTestCase(ViewTestMixin, TestCase):
 
     def setUp(self):
         self.user = UserFactory()
-        self.customer = CompanyFactory()
-        self.unit = UnitFactory(code='pcs', description='pieces')
+        self.customer = factories.CompanyFactory()
+        self.unit = factories.UnitFactory(code='pcs', description='pieces')
 
-        EPNFactory(epn='945382', company=self.customer)
-        EPNFactory(epn='743629', company=self.customer)
+        factories.EPNFactory(epn='945382', company=self.customer)
+        factories.EPNFactory(epn='743629', company=self.customer)
 
         self.csv_file = open(os.path.join(
             settings.APP_ROOT, 'tests/files/cBOM.csv'))
